# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pycherwell.api_client import ApiClient
from pycherwell.exceptions import (
    ApiTypeError,
    ApiValueError
)


class SearchesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def searches_get_quick_search_configuration_for_bus_obs_v1(self, quick_search_configuration_request, **kwargs):  # noqa: E501
        """Get a Quick Search from a list of Business Object IDs  # noqa: E501

        Operation to build a Quick Search configuration that you can use to execute a Quick Search for multiple Business Objects. The configuration  includes supplied Business Object IDs and specific search items with the following options. Use the Option Key to determine if you can change the options. </br></br></br>ChangedOption</br></br>NonFinalStateOption</br></br>SearchAnyWordsOption</br></br>SearchAttachmentsOption</br></br>SearchRelatedOption</br></br>SortByOption</br></br></br>Option Key:</br></br>0 = None (Not selected and cannot select.)</br></br>1 = Use (Selected and cannot clear.)</br></br>2 = Display (Not selected and can select.)</br></br>3 = UseAndDisplay (Selected and can clear.)</br></br></br>SearchTargetType:</br></br>0 = BusOb (Business Object)</br></br>1 = DocRepository (Document Repository)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_quick_search_configuration_for_bus_obs_v1(quick_search_configuration_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QuickSearchConfigurationRequest quick_search_configuration_request: Request containing the Business Object IDs list. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: QuickSearchConfigurationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_quick_search_configuration_for_bus_obs_v1_with_http_info(quick_search_configuration_request, **kwargs)  # noqa: E501

    def searches_get_quick_search_configuration_for_bus_obs_v1_with_http_info(self, quick_search_configuration_request, **kwargs):  # noqa: E501
        """Get a Quick Search from a list of Business Object IDs  # noqa: E501

        Operation to build a Quick Search configuration that you can use to execute a Quick Search for multiple Business Objects. The configuration  includes supplied Business Object IDs and specific search items with the following options. Use the Option Key to determine if you can change the options. </br></br></br>ChangedOption</br></br>NonFinalStateOption</br></br>SearchAnyWordsOption</br></br>SearchAttachmentsOption</br></br>SearchRelatedOption</br></br>SortByOption</br></br></br>Option Key:</br></br>0 = None (Not selected and cannot select.)</br></br>1 = Use (Selected and cannot clear.)</br></br>2 = Display (Not selected and can select.)</br></br>3 = UseAndDisplay (Selected and can clear.)</br></br></br>SearchTargetType:</br></br>0 = BusOb (Business Object)</br></br>1 = DocRepository (Document Repository)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_quick_search_configuration_for_bus_obs_v1_with_http_info(quick_search_configuration_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QuickSearchConfigurationRequest quick_search_configuration_request: Request containing the Business Object IDs list. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(QuickSearchConfigurationResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['quick_search_configuration_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_quick_search_configuration_for_bus_obs_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'quick_search_configuration_request' is set
        if self.api_client.client_side_validation and ('quick_search_configuration_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['quick_search_configuration_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `quick_search_configuration_request` when calling `searches_get_quick_search_configuration_for_bus_obs_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'quick_search_configuration_request' in local_var_params:
            body_params = local_var_params['quick_search_configuration_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getquicksearchconfigurationforbusobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QuickSearchConfigurationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_quick_search_configuration_for_bus_obs_with_view_rights_v1(self, **kwargs):  # noqa: E501
        """Get a Quick Search by Business Objects with view rights  # noqa: E501

        Operation to get a Quick Search configuration that you can use to execute a Quick Search based the current user's Business Object view rights. The configuration  includes supplied Business Object IDs and specific search items with the following options. Use the Option Key to determine if you can change the options.</br></br>ChangedOption</br></br>NonFinalStateOption</br></br>SearchAnyWordsOption</br></br>SearchAttachmentsOption</br></br>SearchRelatedOption</br></br>SortByOption</br></br></br>Option Key:</br></br>0 = None (Not selected and cannot select.)</br></br>1 = Use (Selected and cannot clear.)</br></br>2 = Display (Not selected and can select.)</br></br>3 = UseAndDisplay (Selected and can clear.)</br></br></br>SearchTargetType:</br></br>0 = BusOb (Business Object)</br></br>1 = DocRepository (Document Repository)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_quick_search_configuration_for_bus_obs_with_view_rights_v1(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: QuickSearchConfigurationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_quick_search_configuration_for_bus_obs_with_view_rights_v1_with_http_info(**kwargs)  # noqa: E501

    def searches_get_quick_search_configuration_for_bus_obs_with_view_rights_v1_with_http_info(self, **kwargs):  # noqa: E501
        """Get a Quick Search by Business Objects with view rights  # noqa: E501

        Operation to get a Quick Search configuration that you can use to execute a Quick Search based the current user's Business Object view rights. The configuration  includes supplied Business Object IDs and specific search items with the following options. Use the Option Key to determine if you can change the options.</br></br>ChangedOption</br></br>NonFinalStateOption</br></br>SearchAnyWordsOption</br></br>SearchAttachmentsOption</br></br>SearchRelatedOption</br></br>SortByOption</br></br></br>Option Key:</br></br>0 = None (Not selected and cannot select.)</br></br>1 = Use (Selected and cannot clear.)</br></br>2 = Display (Not selected and can select.)</br></br>3 = UseAndDisplay (Selected and can clear.)</br></br></br>SearchTargetType:</br></br>0 = BusOb (Business Object)</br></br>1 = DocRepository (Document Repository)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_quick_search_configuration_for_bus_obs_with_view_rights_v1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(QuickSearchConfigurationResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_quick_search_configuration_for_bus_obs_with_view_rights_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getquicksearchconfigurationforbusobswithviewrights', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QuickSearchConfigurationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_quick_search_results_v1(self, quick_search_request, **kwargs):  # noqa: E501
        """Execute a Quick Search from a list of Business Object IDs and search text  # noqa: E501

        Operation to execute a Quick Search using a list of Business Object IDs and search text.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_quick_search_results_v1(quick_search_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QuickSearchRequest quick_search_request: Request object listing Business Object IDs and search text. Leave out the entire Business Object IDs parameter and all configured quick search Business Objects will be searched. (required)
        :param bool include_links: Flag to include hyperlinks in results. Default is false. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SimpleResultsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_quick_search_results_v1_with_http_info(quick_search_request, **kwargs)  # noqa: E501

    def searches_get_quick_search_results_v1_with_http_info(self, quick_search_request, **kwargs):  # noqa: E501
        """Execute a Quick Search from a list of Business Object IDs and search text  # noqa: E501

        Operation to execute a Quick Search using a list of Business Object IDs and search text.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_quick_search_results_v1_with_http_info(quick_search_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QuickSearchRequest quick_search_request: Request object listing Business Object IDs and search text. Leave out the entire Business Object IDs parameter and all configured quick search Business Objects will be searched. (required)
        :param bool include_links: Flag to include hyperlinks in results. Default is false. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SimpleResultsList, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['quick_search_request', 'include_links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_quick_search_results_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'quick_search_request' is set
        if self.api_client.client_side_validation and ('quick_search_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['quick_search_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `quick_search_request` when calling `searches_get_quick_search_results_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'include_links' in local_var_params and local_var_params['include_links'] is not None:  # noqa: E501
            query_params.append(('includeLinks', local_var_params['include_links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'quick_search_request' in local_var_params:
            body_params = local_var_params['quick_search_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getquicksearchresults', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SimpleResultsList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_quick_search_specific_results_v1(self, quick_search_specific_request, **kwargs):  # noqa: E501
        """Execute a Quick Search on a specific Business Object  # noqa: E501

        Operation to execute a Quick Search for a specific Business Object ID. Use \"Get a Quick Search from a list of Business Object IDs\" to find values for specific search item options, such as NonFinalStateOption.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_quick_search_specific_results_v1(quick_search_specific_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QuickSearchSpecificRequest quick_search_specific_request: Request object containing the parameters for specific Business Object Quick Search execution. (required)
        :param bool include_schema: Flag to include the schema for the results.
        :param bool include_location_fields: Flag to include location fields in the results.
        :param bool include_links: Flag to include hyperlinks in results. Default is false. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SearchResultsTableResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_quick_search_specific_results_v1_with_http_info(quick_search_specific_request, **kwargs)  # noqa: E501

    def searches_get_quick_search_specific_results_v1_with_http_info(self, quick_search_specific_request, **kwargs):  # noqa: E501
        """Execute a Quick Search on a specific Business Object  # noqa: E501

        Operation to execute a Quick Search for a specific Business Object ID. Use \"Get a Quick Search from a list of Business Object IDs\" to find values for specific search item options, such as NonFinalStateOption.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_quick_search_specific_results_v1_with_http_info(quick_search_specific_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QuickSearchSpecificRequest quick_search_specific_request: Request object containing the parameters for specific Business Object Quick Search execution. (required)
        :param bool include_schema: Flag to include the schema for the results.
        :param bool include_location_fields: Flag to include location fields in the results.
        :param bool include_links: Flag to include hyperlinks in results. Default is false. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SearchResultsTableResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['quick_search_specific_request', 'include_schema', 'include_location_fields', 'include_links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_quick_search_specific_results_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'quick_search_specific_request' is set
        if self.api_client.client_side_validation and ('quick_search_specific_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['quick_search_specific_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `quick_search_specific_request` when calling `searches_get_quick_search_specific_results_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'include_schema' in local_var_params and local_var_params['include_schema'] is not None:  # noqa: E501
            query_params.append(('includeSchema', local_var_params['include_schema']))  # noqa: E501
        if 'include_location_fields' in local_var_params and local_var_params['include_location_fields'] is not None:  # noqa: E501
            query_params.append(('includeLocationFields', local_var_params['include_location_fields']))  # noqa: E501
        if 'include_links' in local_var_params and local_var_params['include_links'] is not None:  # noqa: E501
            query_params.append(('includeLinks', local_var_params['include_links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'quick_search_specific_request' in local_var_params:
            body_params = local_var_params['quick_search_specific_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getquicksearchspecificresults', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchResultsTableResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_quick_search_specific_results_v2(self, quick_search_specific_request, **kwargs):  # noqa: E501
        """Execute a Quick Search on a specific Business Object  # noqa: E501

        Operation to execute a Quick Search for a specific Business Object ID. Use \"Get a Quick Search from a list of Business Object IDs\" to find values for specific search item options, such as NonFinalStateOption.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_quick_search_specific_results_v2(quick_search_specific_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QuickSearchSpecificRequest quick_search_specific_request: Request object containing the parameters for specific Business Object Quick Search execution. (required)
        :param bool include_schema: Flag to include the schema for the results.
        :param bool include_location_fields: Flag to include location fields in the results.
        :param bool include_links: Flag to include hyperlinks in results. Default is false. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: QuickSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_quick_search_specific_results_v2_with_http_info(quick_search_specific_request, **kwargs)  # noqa: E501

    def searches_get_quick_search_specific_results_v2_with_http_info(self, quick_search_specific_request, **kwargs):  # noqa: E501
        """Execute a Quick Search on a specific Business Object  # noqa: E501

        Operation to execute a Quick Search for a specific Business Object ID. Use \"Get a Quick Search from a list of Business Object IDs\" to find values for specific search item options, such as NonFinalStateOption.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_quick_search_specific_results_v2_with_http_info(quick_search_specific_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QuickSearchSpecificRequest quick_search_specific_request: Request object containing the parameters for specific Business Object Quick Search execution. (required)
        :param bool include_schema: Flag to include the schema for the results.
        :param bool include_location_fields: Flag to include location fields in the results.
        :param bool include_links: Flag to include hyperlinks in results. Default is false. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(QuickSearchResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['quick_search_specific_request', 'include_schema', 'include_location_fields', 'include_links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_quick_search_specific_results_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'quick_search_specific_request' is set
        if self.api_client.client_side_validation and ('quick_search_specific_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['quick_search_specific_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `quick_search_specific_request` when calling `searches_get_quick_search_specific_results_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'include_schema' in local_var_params and local_var_params['include_schema'] is not None:  # noqa: E501
            query_params.append(('includeSchema', local_var_params['include_schema']))  # noqa: E501
        if 'include_location_fields' in local_var_params and local_var_params['include_location_fields'] is not None:  # noqa: E501
            query_params.append(('includeLocationFields', local_var_params['include_location_fields']))  # noqa: E501
        if 'include_links' in local_var_params and local_var_params['include_links'] is not None:  # noqa: E501
            query_params.append(('includeLinks', local_var_params['include_links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'quick_search_specific_request' in local_var_params:
            body_params = local_var_params['quick_search_specific_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getquicksearchspecificresults', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QuickSearchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_items_by_association_scope_scope_owner_folder_v1(self, association, scope, scopeowner, folder, **kwargs):  # noqa: E501
        """Get all saved searches by Folder ID  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_scope_scope_owner_folder_v1(association, scope, scopeowner, folder, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param str scope: Use to filter results by scope name or ID. (required)
        :param str scopeowner: Use to filter results by scope owner ID. (required)
        :param str folder: Use to filter results by Search Group folder ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SearchItemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_items_by_association_scope_scope_owner_folder_v1_with_http_info(association, scope, scopeowner, folder, **kwargs)  # noqa: E501

    def searches_get_search_items_by_association_scope_scope_owner_folder_v1_with_http_info(self, association, scope, scopeowner, folder, **kwargs):  # noqa: E501
        """Get all saved searches by Folder ID  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_scope_scope_owner_folder_v1_with_http_info(association, scope, scopeowner, folder, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param str scope: Use to filter results by scope name or ID. (required)
        :param str scopeowner: Use to filter results by scope owner ID. (required)
        :param str folder: Use to filter results by Search Group folder ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SearchItemResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['association', 'scope', 'scopeowner', 'folder', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_items_by_association_scope_scope_owner_folder_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'association' is set
        if self.api_client.client_side_validation and ('association' not in local_var_params or  # noqa: E501
                                                        local_var_params['association'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `association` when calling `searches_get_search_items_by_association_scope_scope_owner_folder_v1`")  # noqa: E501
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `searches_get_search_items_by_association_scope_scope_owner_folder_v1`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `searches_get_search_items_by_association_scope_scope_owner_folder_v1`")  # noqa: E501
        # verify the required parameter 'folder' is set
        if self.api_client.client_side_validation and ('folder' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder` when calling `searches_get_search_items_by_association_scope_scope_owner_folder_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'association' in local_var_params:
            path_params['association'] = local_var_params['association']  # noqa: E501
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501
        if 'folder' in local_var_params:
            path_params['folder'] = local_var_params['folder']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsearchitems/association/{association}/scope/{scope}/scopeowner/{scopeowner}/folder/{folder}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchItemResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_items_by_association_scope_scope_owner_folder_v2(self, association, scope, scopeowner, folder, **kwargs):  # noqa: E501
        """Get all saved searches by Folder ID  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_scope_scope_owner_folder_v2(association, scope, scopeowner, folder, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param str scope: Use to filter results by scope name or ID. (required)
        :param str scopeowner: Use to filter results by scope owner ID. (required)
        :param str folder: Use to filter results by Search Group folder ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_items_by_association_scope_scope_owner_folder_v2_with_http_info(association, scope, scopeowner, folder, **kwargs)  # noqa: E501

    def searches_get_search_items_by_association_scope_scope_owner_folder_v2_with_http_info(self, association, scope, scopeowner, folder, **kwargs):  # noqa: E501
        """Get all saved searches by Folder ID  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_scope_scope_owner_folder_v2_with_http_info(association, scope, scopeowner, folder, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param str scope: Use to filter results by scope name or ID. (required)
        :param str scopeowner: Use to filter results by scope owner ID. (required)
        :param str folder: Use to filter results by Search Group folder ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['association', 'scope', 'scopeowner', 'folder', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_items_by_association_scope_scope_owner_folder_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'association' is set
        if self.api_client.client_side_validation and ('association' not in local_var_params or  # noqa: E501
                                                        local_var_params['association'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `association` when calling `searches_get_search_items_by_association_scope_scope_owner_folder_v2`")  # noqa: E501
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `searches_get_search_items_by_association_scope_scope_owner_folder_v2`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `searches_get_search_items_by_association_scope_scope_owner_folder_v2`")  # noqa: E501
        # verify the required parameter 'folder' is set
        if self.api_client.client_side_validation and ('folder' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder` when calling `searches_get_search_items_by_association_scope_scope_owner_folder_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'association' in local_var_params:
            path_params['association'] = local_var_params['association']  # noqa: E501
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501
        if 'folder' in local_var_params:
            path_params['folder'] = local_var_params['folder']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsearchitems/association/{association}/scope/{scope}/scopeowner/{scopeowner}/folder/{folder}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_items_by_association_scope_scope_owner_v1(self, association, scope, scopeowner, **kwargs):  # noqa: E501
        """Get all saved searches by scope owner (sub scope)  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_scope_scope_owner_v1(association, scope, scopeowner, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param str scope: Use to filter results by scope name or ID. (required)
        :param str scopeowner: Use to filter results by scope owner ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SearchItemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_items_by_association_scope_scope_owner_v1_with_http_info(association, scope, scopeowner, **kwargs)  # noqa: E501

    def searches_get_search_items_by_association_scope_scope_owner_v1_with_http_info(self, association, scope, scopeowner, **kwargs):  # noqa: E501
        """Get all saved searches by scope owner (sub scope)  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_scope_scope_owner_v1_with_http_info(association, scope, scopeowner, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param str scope: Use to filter results by scope name or ID. (required)
        :param str scopeowner: Use to filter results by scope owner ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SearchItemResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['association', 'scope', 'scopeowner', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_items_by_association_scope_scope_owner_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'association' is set
        if self.api_client.client_side_validation and ('association' not in local_var_params or  # noqa: E501
                                                        local_var_params['association'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `association` when calling `searches_get_search_items_by_association_scope_scope_owner_v1`")  # noqa: E501
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `searches_get_search_items_by_association_scope_scope_owner_v1`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `searches_get_search_items_by_association_scope_scope_owner_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'association' in local_var_params:
            path_params['association'] = local_var_params['association']  # noqa: E501
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsearchitems/association/{association}/scope/{scope}/scopeowner/{scopeowner}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchItemResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_items_by_association_scope_scope_owner_v2(self, association, scope, scopeowner, **kwargs):  # noqa: E501
        """Get all saved searches by scope owner (sub scope)  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_scope_scope_owner_v2(association, scope, scopeowner, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param str scope: Use to filter results by scope name or ID. (required)
        :param str scopeowner: Use to filter results by scope owner ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_items_by_association_scope_scope_owner_v2_with_http_info(association, scope, scopeowner, **kwargs)  # noqa: E501

    def searches_get_search_items_by_association_scope_scope_owner_v2_with_http_info(self, association, scope, scopeowner, **kwargs):  # noqa: E501
        """Get all saved searches by scope owner (sub scope)  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_scope_scope_owner_v2_with_http_info(association, scope, scopeowner, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param str scope: Use to filter results by scope name or ID. (required)
        :param str scopeowner: Use to filter results by scope owner ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['association', 'scope', 'scopeowner', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_items_by_association_scope_scope_owner_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'association' is set
        if self.api_client.client_side_validation and ('association' not in local_var_params or  # noqa: E501
                                                        local_var_params['association'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `association` when calling `searches_get_search_items_by_association_scope_scope_owner_v2`")  # noqa: E501
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `searches_get_search_items_by_association_scope_scope_owner_v2`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `searches_get_search_items_by_association_scope_scope_owner_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'association' in local_var_params:
            path_params['association'] = local_var_params['association']  # noqa: E501
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsearchitems/association/{association}/scope/{scope}/scopeowner/{scopeowner}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_items_by_association_scope_v1(self, association, scope, **kwargs):  # noqa: E501
        """Get all saved searches by scope  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_scope_v1(association, scope, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param str scope: Use to filter results by scope name or ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SearchItemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_items_by_association_scope_v1_with_http_info(association, scope, **kwargs)  # noqa: E501

    def searches_get_search_items_by_association_scope_v1_with_http_info(self, association, scope, **kwargs):  # noqa: E501
        """Get all saved searches by scope  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_scope_v1_with_http_info(association, scope, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param str scope: Use to filter results by scope name or ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SearchItemResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['association', 'scope', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_items_by_association_scope_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'association' is set
        if self.api_client.client_side_validation and ('association' not in local_var_params or  # noqa: E501
                                                        local_var_params['association'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `association` when calling `searches_get_search_items_by_association_scope_v1`")  # noqa: E501
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `searches_get_search_items_by_association_scope_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'association' in local_var_params:
            path_params['association'] = local_var_params['association']  # noqa: E501
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsearchitems/association/{association}/scope/{scope}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchItemResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_items_by_association_scope_v2(self, association, scope, **kwargs):  # noqa: E501
        """Get all saved searches by scope  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_scope_v2(association, scope, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param str scope: Use to filter results by scope name or ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_items_by_association_scope_v2_with_http_info(association, scope, **kwargs)  # noqa: E501

    def searches_get_search_items_by_association_scope_v2_with_http_info(self, association, scope, **kwargs):  # noqa: E501
        """Get all saved searches by scope  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_scope_v2_with_http_info(association, scope, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param str scope: Use to filter results by scope name or ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['association', 'scope', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_items_by_association_scope_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'association' is set
        if self.api_client.client_side_validation and ('association' not in local_var_params or  # noqa: E501
                                                        local_var_params['association'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `association` when calling `searches_get_search_items_by_association_scope_v2`")  # noqa: E501
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `searches_get_search_items_by_association_scope_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'association' in local_var_params:
            path_params['association'] = local_var_params['association']  # noqa: E501
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsearchitems/association/{association}/scope/{scope}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_items_by_association_v1(self, association, **kwargs):  # noqa: E501
        """Get all saved searches by Business Object association  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_v1(association, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SearchItemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_items_by_association_v1_with_http_info(association, **kwargs)  # noqa: E501

    def searches_get_search_items_by_association_v1_with_http_info(self, association, **kwargs):  # noqa: E501
        """Get all saved searches by Business Object association  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_v1_with_http_info(association, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SearchItemResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['association', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_items_by_association_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'association' is set
        if self.api_client.client_side_validation and ('association' not in local_var_params or  # noqa: E501
                                                        local_var_params['association'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `association` when calling `searches_get_search_items_by_association_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'association' in local_var_params:
            path_params['association'] = local_var_params['association']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsearchitems/association/{association}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchItemResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_items_by_association_v2(self, association, **kwargs):  # noqa: E501
        """Get all saved searches by Business Object association  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_v2(association, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_items_by_association_v2_with_http_info(association, **kwargs)  # noqa: E501

    def searches_get_search_items_by_association_v2_with_http_info(self, association, **kwargs):  # noqa: E501
        """Get all saved searches by Business Object association  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_by_association_v2_with_http_info(association, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Use to filter results by Business Object association ID. (required)
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['association', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_items_by_association_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'association' is set
        if self.api_client.client_side_validation and ('association' not in local_var_params or  # noqa: E501
                                                        local_var_params['association'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `association` when calling `searches_get_search_items_by_association_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'association' in local_var_params:
            path_params['association'] = local_var_params['association']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsearchitems/association/{association}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_items_v1(self, **kwargs):  # noqa: E501
        """Get all saved searches by default Business Object association  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_v1(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SearchItemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_items_v1_with_http_info(**kwargs)  # noqa: E501

    def searches_get_search_items_v1_with_http_info(self, **kwargs):  # noqa: E501
        """Get all saved searches by default Business Object association  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_v1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SearchItemResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_items_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsearchitems', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchItemResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_items_v2(self, **kwargs):  # noqa: E501
        """Get all saved searches by default Business Object association  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_v2(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_items_v2_with_http_info(**kwargs)  # noqa: E501

    def searches_get_search_items_v2_with_http_info(self, **kwargs):  # noqa: E501
        """Get all saved searches by default Business Object association  # noqa: E501

        Operation that returns a tree of saved queries, including scope, search name, IDs, and location within the tree.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_items_v2_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool links: Flag to include hyperlinks in results. Default is false. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_items_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getsearchitems', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_results_ad_hoc_v1(self, search_results_request, **kwargs):  # noqa: E501
        """Run an ad-hoc search  # noqa: E501

        Operation that runs an ad-hoc Business Object search. To execute a search with Prompts, the PromptId and Value are required in the Prompt request object.</br></br>PromptType is a FieldSubType enum as described below:</br>FieldSubType</br>None = 0</br>Text = 1</br>Number = 2</br>DateTime = 3</br>Logical = 4</br>Binary = 5</br>DateOnly = 6</br>TimeOnly = 7</br>Json = 8</br>JsonArray = 9</br>Xml = 10</br>XmlCollection = 11</br>TimeValue = 12</br>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_results_ad_hoc_v1(search_results_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SearchResultsRequest search_results_request: Request object to specify search parameters. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SearchResultsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_results_ad_hoc_v1_with_http_info(search_results_request, **kwargs)  # noqa: E501

    def searches_get_search_results_ad_hoc_v1_with_http_info(self, search_results_request, **kwargs):  # noqa: E501
        """Run an ad-hoc search  # noqa: E501

        Operation that runs an ad-hoc Business Object search. To execute a search with Prompts, the PromptId and Value are required in the Prompt request object.</br></br>PromptType is a FieldSubType enum as described below:</br>FieldSubType</br>None = 0</br>Text = 1</br>Number = 2</br>DateTime = 3</br>Logical = 4</br>Binary = 5</br>DateOnly = 6</br>TimeOnly = 7</br>Json = 8</br>JsonArray = 9</br>Xml = 10</br>XmlCollection = 11</br>TimeValue = 12</br>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_results_ad_hoc_v1_with_http_info(search_results_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SearchResultsRequest search_results_request: Request object to specify search parameters. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SearchResultsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['search_results_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_results_ad_hoc_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'search_results_request' is set
        if self.api_client.client_side_validation and ('search_results_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['search_results_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `search_results_request` when calling `searches_get_search_results_ad_hoc_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'search_results_request' in local_var_params:
            body_params = local_var_params['search_results_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsearchresults', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchResultsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_results_by_id_v1(self, association, scope, scopeowner, searchid, **kwargs):  # noqa: E501
        """Run a saved search by internal ID  # noqa: E501

        Operation that returns the paged results of a saved search. When the search contains Prompts, the response contains the Prompt. Send the Prompt and the original operation parameters to  SearchResultsRequest to the getsearchresults ad-hoc http post operation.</br></br>PromptType is a FieldSubType enum as described below:</br>FieldSubType</br>None = 0</br>Text = 1</br>Number = 2</br>DateTime = 3</br>Logical = 4</br>Binary = 5</br>DateOnly = 6</br>TimeOnly = 7</br>Json = 8</br>JsonArray = 9</br>Xml = 10</br>XmlCollection = 11</br>TimeValue = 12</br>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_results_by_id_v1(association, scope, scopeowner, searchid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Specify the Business Object association ID for the saved search. (required)
        :param str scope: Specify the scope name or ID for the saved search. (required)
        :param str scopeowner: Specify the scope owner ID for the saved search. Use (None) when no scope owner exists. (required)
        :param str searchid: Specify the internal ID for the saved search. Use \"Run a saved search by name\" if you do not have the internal ID. (required)
        :param str search_term: Specify search text filter the results. Example: Use \"Service Request\" to filter Incident results to include only service requests.
        :param int pagenumber: Specify the page number of the result set to return.
        :param int pagesize: Specify the number of rows to return per page.
        :param bool includeschema: Use to include the table schema of the saved search. If false, results contain the fieldid and field value without field information. Default is false.
        :param bool results_as_simple_results_list: Indicates if the results should be returned in a simple results list format or a table format. Default is a table format.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SearchResultsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_results_by_id_v1_with_http_info(association, scope, scopeowner, searchid, **kwargs)  # noqa: E501

    def searches_get_search_results_by_id_v1_with_http_info(self, association, scope, scopeowner, searchid, **kwargs):  # noqa: E501
        """Run a saved search by internal ID  # noqa: E501

        Operation that returns the paged results of a saved search. When the search contains Prompts, the response contains the Prompt. Send the Prompt and the original operation parameters to  SearchResultsRequest to the getsearchresults ad-hoc http post operation.</br></br>PromptType is a FieldSubType enum as described below:</br>FieldSubType</br>None = 0</br>Text = 1</br>Number = 2</br>DateTime = 3</br>Logical = 4</br>Binary = 5</br>DateOnly = 6</br>TimeOnly = 7</br>Json = 8</br>JsonArray = 9</br>Xml = 10</br>XmlCollection = 11</br>TimeValue = 12</br>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_results_by_id_v1_with_http_info(association, scope, scopeowner, searchid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Specify the Business Object association ID for the saved search. (required)
        :param str scope: Specify the scope name or ID for the saved search. (required)
        :param str scopeowner: Specify the scope owner ID for the saved search. Use (None) when no scope owner exists. (required)
        :param str searchid: Specify the internal ID for the saved search. Use \"Run a saved search by name\" if you do not have the internal ID. (required)
        :param str search_term: Specify search text filter the results. Example: Use \"Service Request\" to filter Incident results to include only service requests.
        :param int pagenumber: Specify the page number of the result set to return.
        :param int pagesize: Specify the number of rows to return per page.
        :param bool includeschema: Use to include the table schema of the saved search. If false, results contain the fieldid and field value without field information. Default is false.
        :param bool results_as_simple_results_list: Indicates if the results should be returned in a simple results list format or a table format. Default is a table format.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SearchResultsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['association', 'scope', 'scopeowner', 'searchid', 'search_term', 'pagenumber', 'pagesize', 'includeschema', 'results_as_simple_results_list']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_results_by_id_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'association' is set
        if self.api_client.client_side_validation and ('association' not in local_var_params or  # noqa: E501
                                                        local_var_params['association'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `association` when calling `searches_get_search_results_by_id_v1`")  # noqa: E501
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `searches_get_search_results_by_id_v1`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `searches_get_search_results_by_id_v1`")  # noqa: E501
        # verify the required parameter 'searchid' is set
        if self.api_client.client_side_validation and ('searchid' not in local_var_params or  # noqa: E501
                                                        local_var_params['searchid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `searchid` when calling `searches_get_search_results_by_id_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'association' in local_var_params:
            path_params['association'] = local_var_params['association']  # noqa: E501
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501
        if 'searchid' in local_var_params:
            path_params['searchid'] = local_var_params['searchid']  # noqa: E501

        query_params = []
        if 'search_term' in local_var_params and local_var_params['search_term'] is not None:  # noqa: E501
            query_params.append(('searchTerm', local_var_params['search_term']))  # noqa: E501
        if 'pagenumber' in local_var_params and local_var_params['pagenumber'] is not None:  # noqa: E501
            query_params.append(('pagenumber', local_var_params['pagenumber']))  # noqa: E501
        if 'pagesize' in local_var_params and local_var_params['pagesize'] is not None:  # noqa: E501
            query_params.append(('pagesize', local_var_params['pagesize']))  # noqa: E501
        if 'includeschema' in local_var_params and local_var_params['includeschema'] is not None:  # noqa: E501
            query_params.append(('includeschema', local_var_params['includeschema']))  # noqa: E501
        if 'results_as_simple_results_list' in local_var_params and local_var_params['results_as_simple_results_list'] is not None:  # noqa: E501
            query_params.append(('resultsAsSimpleResultsList', local_var_params['results_as_simple_results_list']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsearchresults/association/{association}/scope/{scope}/scopeowner/{scopeowner}/searchid/{searchid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchResultsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_results_by_name_v1(self, association, scope, scopeowner, searchname, **kwargs):  # noqa: E501
        """Run a saved search by name  # noqa: E501

        Operation that returns the paged results of a saved search. When the search contains Prompts, the response contains the Prompt. Send the Prompt and the original operation parameters to  SearchResultsRequest to the getsearchresults ad-hoc http post operation.</br></br>PromptType is a FieldSubType enum as described below:</br>FieldSubType</br>None = 0</br>Text = 1</br>Number = 2</br>DateTime = 3</br>Logical = 4</br>Binary = 5</br>DateOnly = 6</br>TimeOnly = 7</br>Json = 8</br>JsonArray = 9</br>Xml = 10</br>XmlCollection = 11</br>TimeValue = 12</br>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_results_by_name_v1(association, scope, scopeowner, searchname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Specify the Business Object association ID for the saved search. (required)
        :param str scope: Specify the scope name or ID for the saved search. (required)
        :param str scopeowner: Specify the scope owner ID for the saved search. Use (None) when no scope owner exists. (required)
        :param str searchname: Specify the name of the saved search. (required)
        :param str search_term: Specify search text filter the results. Example: Use \"Service Request\" to filter Incident results to include only service requests.
        :param int pagenumber: Specify the page number of the result set to return.
        :param int pagesize: Specify the number of rows to return per page.
        :param bool includeschema: Use to include the table schema of the saved search. If false, results contain the fieldid and field value without field information. Default is false.
        :param bool results_as_simple_results_list: Indicates if the results should be returned in a simple results list format or a table format. Default is a table format.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SearchResultsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_results_by_name_v1_with_http_info(association, scope, scopeowner, searchname, **kwargs)  # noqa: E501

    def searches_get_search_results_by_name_v1_with_http_info(self, association, scope, scopeowner, searchname, **kwargs):  # noqa: E501
        """Run a saved search by name  # noqa: E501

        Operation that returns the paged results of a saved search. When the search contains Prompts, the response contains the Prompt. Send the Prompt and the original operation parameters to  SearchResultsRequest to the getsearchresults ad-hoc http post operation.</br></br>PromptType is a FieldSubType enum as described below:</br>FieldSubType</br>None = 0</br>Text = 1</br>Number = 2</br>DateTime = 3</br>Logical = 4</br>Binary = 5</br>DateOnly = 6</br>TimeOnly = 7</br>Json = 8</br>JsonArray = 9</br>Xml = 10</br>XmlCollection = 11</br>TimeValue = 12</br>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_results_by_name_v1_with_http_info(association, scope, scopeowner, searchname, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Specify the Business Object association ID for the saved search. (required)
        :param str scope: Specify the scope name or ID for the saved search. (required)
        :param str scopeowner: Specify the scope owner ID for the saved search. Use (None) when no scope owner exists. (required)
        :param str searchname: Specify the name of the saved search. (required)
        :param str search_term: Specify search text filter the results. Example: Use \"Service Request\" to filter Incident results to include only service requests.
        :param int pagenumber: Specify the page number of the result set to return.
        :param int pagesize: Specify the number of rows to return per page.
        :param bool includeschema: Use to include the table schema of the saved search. If false, results contain the fieldid and field value without field information. Default is false.
        :param bool results_as_simple_results_list: Indicates if the results should be returned in a simple results list format or a table format. Default is a table format.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SearchResultsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['association', 'scope', 'scopeowner', 'searchname', 'search_term', 'pagenumber', 'pagesize', 'includeschema', 'results_as_simple_results_list']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_results_by_name_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'association' is set
        if self.api_client.client_side_validation and ('association' not in local_var_params or  # noqa: E501
                                                        local_var_params['association'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `association` when calling `searches_get_search_results_by_name_v1`")  # noqa: E501
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `searches_get_search_results_by_name_v1`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `searches_get_search_results_by_name_v1`")  # noqa: E501
        # verify the required parameter 'searchname' is set
        if self.api_client.client_side_validation and ('searchname' not in local_var_params or  # noqa: E501
                                                        local_var_params['searchname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `searchname` when calling `searches_get_search_results_by_name_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'association' in local_var_params:
            path_params['association'] = local_var_params['association']  # noqa: E501
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501
        if 'searchname' in local_var_params:
            path_params['searchname'] = local_var_params['searchname']  # noqa: E501

        query_params = []
        if 'search_term' in local_var_params and local_var_params['search_term'] is not None:  # noqa: E501
            query_params.append(('searchTerm', local_var_params['search_term']))  # noqa: E501
        if 'pagenumber' in local_var_params and local_var_params['pagenumber'] is not None:  # noqa: E501
            query_params.append(('pagenumber', local_var_params['pagenumber']))  # noqa: E501
        if 'pagesize' in local_var_params and local_var_params['pagesize'] is not None:  # noqa: E501
            query_params.append(('pagesize', local_var_params['pagesize']))  # noqa: E501
        if 'includeschema' in local_var_params and local_var_params['includeschema'] is not None:  # noqa: E501
            query_params.append(('includeschema', local_var_params['includeschema']))  # noqa: E501
        if 'results_as_simple_results_list' in local_var_params and local_var_params['results_as_simple_results_list'] is not None:  # noqa: E501
            query_params.append(('resultsAsSimpleResultsList', local_var_params['results_as_simple_results_list']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsearchresults/association/{association}/scope/{scope}/scopeowner/{scopeowner}/searchname/{searchname}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchResultsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_results_export_ad_hoc_v1(self, export_search_results_request, **kwargs):  # noqa: E501
        """Export an ad-hoc search  # noqa: E501

        Operation that returns an ad-hoc search in a specified export format: 0=CSV, 1=Excel, 2=Tab, 3=Word, 4=Custom Separator, 5=Simple JSON. To execute a search with Prompts, the PromptId and Value are required in the Prompt request object.</br></br>PromptType is a FieldSubType enum as described below:</br>FieldSubType</br>None = 0</br>Text = 1</br>Number = 2</br>DateTime = 3</br>Logical = 4</br>Binary = 5</br>DateOnly = 6</br>TimeOnly = 7</br>Json = 8</br>JsonArray = 9</br>Xml = 10</br>XmlCollection = 11</br>TimeValue = 12</br>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_results_export_ad_hoc_v1(export_search_results_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ExportSearchResultsRequest export_search_results_request: Request object to specify search parameters and export format. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_results_export_ad_hoc_v1_with_http_info(export_search_results_request, **kwargs)  # noqa: E501

    def searches_get_search_results_export_ad_hoc_v1_with_http_info(self, export_search_results_request, **kwargs):  # noqa: E501
        """Export an ad-hoc search  # noqa: E501

        Operation that returns an ad-hoc search in a specified export format: 0=CSV, 1=Excel, 2=Tab, 3=Word, 4=Custom Separator, 5=Simple JSON. To execute a search with Prompts, the PromptId and Value are required in the Prompt request object.</br></br>PromptType is a FieldSubType enum as described below:</br>FieldSubType</br>None = 0</br>Text = 1</br>Number = 2</br>DateTime = 3</br>Logical = 4</br>Binary = 5</br>DateOnly = 6</br>TimeOnly = 7</br>Json = 8</br>JsonArray = 9</br>Xml = 10</br>XmlCollection = 11</br>TimeValue = 12</br>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_results_export_ad_hoc_v1_with_http_info(export_search_results_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ExportSearchResultsRequest export_search_results_request: Request object to specify search parameters and export format. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['export_search_results_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_results_export_ad_hoc_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'export_search_results_request' is set
        if self.api_client.client_side_validation and ('export_search_results_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['export_search_results_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `export_search_results_request` when calling `searches_get_search_results_export_ad_hoc_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'export_search_results_request' in local_var_params:
            body_params = local_var_params['export_search_results_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsearchresultsexport', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_results_export_by_id_v1(self, association, scope, scopeowner, searchid, exportformat, **kwargs):  # noqa: E501
        """Export a saved search by ID  # noqa: E501

        Operation that returns the paged results of a saved search in a specified format. When the search contains Prompts, the response contains the Prompt. Send the Prompt and the original operation parameters to  SearchResultsRequest to the getsearchresultsexport ad-hoc http post operation.</br></br>PromptType is a FieldSubType enum as described below:</br>FieldSubType</br>None = 0</br>Text = 1</br>Number = 2</br>DateTime = 3</br>Logical = 4</br>Binary = 5</br>DateOnly = 6</br>TimeOnly = 7</br>Json = 8</br>JsonArray = 9</br>Xml = 10</br>XmlCollection = 11</br>TimeValue = 12</br>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_results_export_by_id_v1(association, scope, scopeowner, searchid, exportformat, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Specify the Business Object association ID for the saved search. (required)
        :param str scope: Specify the scope name or ID for the saved search. (required)
        :param str scopeowner: Specify the scope owner ID for the saved search. Use (None) when no scope owner exists. (required)
        :param str searchid: Specify the internal ID for the saved search. Use \"Run a saved search by name\" if you do not have the internal ID. (required)
        :param str exportformat: Specify the format of the export (required)
        :param str search_term: Specify search text filter the results. Example: Use \"Service Request\" to filter Incident results to include only service requests.
        :param int pagenumber: Specify the page number of the result set to return.
        :param int pagesize: Specify the number of rows to return per page.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_results_export_by_id_v1_with_http_info(association, scope, scopeowner, searchid, exportformat, **kwargs)  # noqa: E501

    def searches_get_search_results_export_by_id_v1_with_http_info(self, association, scope, scopeowner, searchid, exportformat, **kwargs):  # noqa: E501
        """Export a saved search by ID  # noqa: E501

        Operation that returns the paged results of a saved search in a specified format. When the search contains Prompts, the response contains the Prompt. Send the Prompt and the original operation parameters to  SearchResultsRequest to the getsearchresultsexport ad-hoc http post operation.</br></br>PromptType is a FieldSubType enum as described below:</br>FieldSubType</br>None = 0</br>Text = 1</br>Number = 2</br>DateTime = 3</br>Logical = 4</br>Binary = 5</br>DateOnly = 6</br>TimeOnly = 7</br>Json = 8</br>JsonArray = 9</br>Xml = 10</br>XmlCollection = 11</br>TimeValue = 12</br>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_results_export_by_id_v1_with_http_info(association, scope, scopeowner, searchid, exportformat, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Specify the Business Object association ID for the saved search. (required)
        :param str scope: Specify the scope name or ID for the saved search. (required)
        :param str scopeowner: Specify the scope owner ID for the saved search. Use (None) when no scope owner exists. (required)
        :param str searchid: Specify the internal ID for the saved search. Use \"Run a saved search by name\" if you do not have the internal ID. (required)
        :param str exportformat: Specify the format of the export (required)
        :param str search_term: Specify search text filter the results. Example: Use \"Service Request\" to filter Incident results to include only service requests.
        :param int pagenumber: Specify the page number of the result set to return.
        :param int pagesize: Specify the number of rows to return per page.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['association', 'scope', 'scopeowner', 'searchid', 'exportformat', 'search_term', 'pagenumber', 'pagesize']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_results_export_by_id_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'association' is set
        if self.api_client.client_side_validation and ('association' not in local_var_params or  # noqa: E501
                                                        local_var_params['association'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `association` when calling `searches_get_search_results_export_by_id_v1`")  # noqa: E501
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `searches_get_search_results_export_by_id_v1`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `searches_get_search_results_export_by_id_v1`")  # noqa: E501
        # verify the required parameter 'searchid' is set
        if self.api_client.client_side_validation and ('searchid' not in local_var_params or  # noqa: E501
                                                        local_var_params['searchid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `searchid` when calling `searches_get_search_results_export_by_id_v1`")  # noqa: E501
        # verify the required parameter 'exportformat' is set
        if self.api_client.client_side_validation and ('exportformat' not in local_var_params or  # noqa: E501
                                                        local_var_params['exportformat'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `exportformat` when calling `searches_get_search_results_export_by_id_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'association' in local_var_params:
            path_params['association'] = local_var_params['association']  # noqa: E501
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501
        if 'searchid' in local_var_params:
            path_params['searchid'] = local_var_params['searchid']  # noqa: E501
        if 'exportformat' in local_var_params:
            path_params['exportformat'] = local_var_params['exportformat']  # noqa: E501

        query_params = []
        if 'search_term' in local_var_params and local_var_params['search_term'] is not None:  # noqa: E501
            query_params.append(('searchTerm', local_var_params['search_term']))  # noqa: E501
        if 'pagenumber' in local_var_params and local_var_params['pagenumber'] is not None:  # noqa: E501
            query_params.append(('pagenumber', local_var_params['pagenumber']))  # noqa: E501
        if 'pagesize' in local_var_params and local_var_params['pagesize'] is not None:  # noqa: E501
            query_params.append(('pagesize', local_var_params['pagesize']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsearchresultsexport/association/{association}/scope/{scope}/scopeowner/{scopeowner}/searchid/{searchid}/exportformat/{exportformat}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def searches_get_search_results_export_by_name_v1(self, association, scope, scopeowner, searchname, exportformat, **kwargs):  # noqa: E501
        """Export a saved search by name  # noqa: E501

        Operation that returns the paged results of a saved search in a specified format. When the search contains Prompts, the response contains the Prompt. Send the Prompt and the original operation parameters to  SearchResultsRequest to the getsearchresultsexport ad-hoc http post operation.</br></br>PromptType is a FieldSubType enum as described below:</br>FieldSubType</br>None = 0</br>Text = 1</br>Number = 2</br>DateTime = 3</br>Logical = 4</br>Binary = 5</br>DateOnly = 6</br>TimeOnly = 7</br>Json = 8</br>JsonArray = 9</br>Xml = 10</br>XmlCollection = 11</br>TimeValue = 12</br>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_results_export_by_name_v1(association, scope, scopeowner, searchname, exportformat, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Specify the Business Object association ID for the saved search. (required)
        :param str scope: Specify the scope name or ID for the saved search. (required)
        :param str scopeowner: Specify the scope owner ID for the saved search. Use (None) when no scope owner exists. (required)
        :param str searchname: Specify the name of the saved search. (required)
        :param str exportformat: Specify the format of the export (required)
        :param str search_term: Specify search text filter the results. Example: Use \"Service Request\" to filter Incident results to include only service requests.
        :param int pagenumber: Specify the page number of the result set to return.
        :param int pagesize: Specify the number of rows to return per page.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.searches_get_search_results_export_by_name_v1_with_http_info(association, scope, scopeowner, searchname, exportformat, **kwargs)  # noqa: E501

    def searches_get_search_results_export_by_name_v1_with_http_info(self, association, scope, scopeowner, searchname, exportformat, **kwargs):  # noqa: E501
        """Export a saved search by name  # noqa: E501

        Operation that returns the paged results of a saved search in a specified format. When the search contains Prompts, the response contains the Prompt. Send the Prompt and the original operation parameters to  SearchResultsRequest to the getsearchresultsexport ad-hoc http post operation.</br></br>PromptType is a FieldSubType enum as described below:</br>FieldSubType</br>None = 0</br>Text = 1</br>Number = 2</br>DateTime = 3</br>Logical = 4</br>Binary = 5</br>DateOnly = 6</br>TimeOnly = 7</br>Json = 8</br>JsonArray = 9</br>Xml = 10</br>XmlCollection = 11</br>TimeValue = 12</br>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.searches_get_search_results_export_by_name_v1_with_http_info(association, scope, scopeowner, searchname, exportformat, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str association: Specify the Business Object association ID for the saved search. (required)
        :param str scope: Specify the scope name or ID for the saved search. (required)
        :param str scopeowner: Specify the scope owner ID for the saved search. Use (None) when no scope owner exists. (required)
        :param str searchname: Specify the name of the saved search. (required)
        :param str exportformat: Specify the format of the export (required)
        :param str search_term: Specify search text filter the results. Example: Use \"Service Request\" to filter Incident results to include only service requests.
        :param int pagenumber: Specify the page number of the result set to return.
        :param int pagesize: Specify the number of rows to return per page.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['association', 'scope', 'scopeowner', 'searchname', 'exportformat', 'search_term', 'pagenumber', 'pagesize']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method searches_get_search_results_export_by_name_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'association' is set
        if self.api_client.client_side_validation and ('association' not in local_var_params or  # noqa: E501
                                                        local_var_params['association'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `association` when calling `searches_get_search_results_export_by_name_v1`")  # noqa: E501
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `searches_get_search_results_export_by_name_v1`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `searches_get_search_results_export_by_name_v1`")  # noqa: E501
        # verify the required parameter 'searchname' is set
        if self.api_client.client_side_validation and ('searchname' not in local_var_params or  # noqa: E501
                                                        local_var_params['searchname'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `searchname` when calling `searches_get_search_results_export_by_name_v1`")  # noqa: E501
        # verify the required parameter 'exportformat' is set
        if self.api_client.client_side_validation and ('exportformat' not in local_var_params or  # noqa: E501
                                                        local_var_params['exportformat'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `exportformat` when calling `searches_get_search_results_export_by_name_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'association' in local_var_params:
            path_params['association'] = local_var_params['association']  # noqa: E501
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501
        if 'searchname' in local_var_params:
            path_params['searchname'] = local_var_params['searchname']  # noqa: E501
        if 'exportformat' in local_var_params:
            path_params['exportformat'] = local_var_params['exportformat']  # noqa: E501

        query_params = []
        if 'search_term' in local_var_params and local_var_params['search_term'] is not None:  # noqa: E501
            query_params.append(('searchTerm', local_var_params['search_term']))  # noqa: E501
        if 'pagenumber' in local_var_params and local_var_params['pagenumber'] is not None:  # noqa: E501
            query_params.append(('pagenumber', local_var_params['pagenumber']))  # noqa: E501
        if 'pagesize' in local_var_params and local_var_params['pagesize'] is not None:  # noqa: E501
            query_params.append(('pagesize', local_var_params['pagesize']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getsearchresultsexport/association/{association}/scope/{scope}/scopeowner/{scopeowner}/searchname/{searchname}/exportformat/{exportformat}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class RemoveUserFromTeamResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'team_id': 'str',
        'user_record_id': 'str',
        'error_code': 'str',
        'error_message': 'str',
        'has_error': 'bool'
    }

    attribute_map = {
        'team_id': 'teamId',
        'user_record_id': 'userRecordId',
        'error_code': 'errorCode',
        'error_message': 'errorMessage',
        'has_error': 'hasError'
    }

    def __init__(self, team_id=None, user_record_id=None, error_code=None, error_message=None, has_error=None, local_vars_configuration=None):  # noqa: E501
        """RemoveUserFromTeamResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._team_id = None
        self._user_record_id = None
        self._error_code = None
        self._error_message = None
        self._has_error = None
        self.discriminator = None

        if team_id is not None:
            self.team_id = team_id
        if user_record_id is not None:
            self.user_record_id = user_record_id
        if error_code is not None:
            self.error_code = error_code
        if error_message is not None:
            self.error_message = error_message
        if has_error is not None:
            self.has_error = has_error

    @property
    def team_id(self):
        """Gets the team_id of this RemoveUserFromTeamResponse.  # noqa: E501


        :return: The team_id of this RemoveUserFromTeamResponse.  # noqa: E501
        :rtype: str
        """
        return self._team_id

    @team_id.setter
    def team_id(self, team_id):
        """Sets the team_id of this RemoveUserFromTeamResponse.


        :param team_id: The team_id of this RemoveUserFromTeamResponse.  # noqa: E501
        :type: str
        """

        self._team_id = team_id

    @property
    def user_record_id(self):
        """Gets the user_record_id of this RemoveUserFromTeamResponse.  # noqa: E501


        :return: The user_record_id of this RemoveUserFromTeamResponse.  # noqa: E501
        :rtype: str
        """
        return self._user_record_id

    @user_record_id.setter
    def user_record_id(self, user_record_id):
        """Sets the user_record_id of this RemoveUserFromTeamResponse.


        :param user_record_id: The user_record_id of this RemoveUserFromTeamResponse.  # noqa: E501
        :type: str
        """

        self._user_record_id = user_record_id

    @property
    def error_code(self):
        """Gets the error_code of this RemoveUserFromTeamResponse.  # noqa: E501


        :return: The error_code of this RemoveUserFromTeamResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this RemoveUserFromTeamResponse.


        :param error_code: The error_code of this RemoveUserFromTeamResponse.  # noqa: E501
        :type: str
        """

        self._error_code = error_code

    @property
    def error_message(self):
        """Gets the error_message of this RemoveUserFromTeamResponse.  # noqa: E501


        :return: The error_message of this RemoveUserFromTeamResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this RemoveUserFromTeamResponse.


        :param error_message: The error_message of this RemoveUserFromTeamResponse.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def has_error(self):
        """Gets the has_error of this RemoveUserFromTeamResponse.  # noqa: E501


        :return: The has_error of this RemoveUserFromTeamResponse.  # noqa: E501
        :rtype: bool
        """
        return self._has_error

    @has_error.setter
    def has_error(self, has_error):
        """Sets the has_error of this RemoveUserFromTeamResponse.


        :param has_error: The has_error of this RemoveUserFromTeamResponse.  # noqa: E501
        :type: bool
        """

        self._has_error = has_error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoveUserFromTeamResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RemoveUserFromTeamResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class Action(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'action_command': 'str',
        'action_type': 'str',
        'always_text_and_image': 'bool',
        'begin_group': 'bool',
        'child_actions': 'list[Action]',
        'dependencies': 'list[str]',
        'display_text': 'str',
        'enabled': 'bool',
        'gallery_image': 'str',
        'help_text': 'str',
        'login_enabled_mode': 'str',
        'login_visibility_mode': 'str',
        'name': 'str',
        'parameters': 'list[KeyValuePairStringString]',
        'visible': 'bool'
    }

    attribute_map = {
        'action_command': 'actionCommand',
        'action_type': 'actionType',
        'always_text_and_image': 'alwaysTextAndImage',
        'begin_group': 'beginGroup',
        'child_actions': 'childActions',
        'dependencies': 'dependencies',
        'display_text': 'displayText',
        'enabled': 'enabled',
        'gallery_image': 'galleryImage',
        'help_text': 'helpText',
        'login_enabled_mode': 'loginEnabledMode',
        'login_visibility_mode': 'loginVisibilityMode',
        'name': 'name',
        'parameters': 'parameters',
        'visible': 'visible'
    }

    def __init__(self, action_command=None, action_type=None, always_text_and_image=None, begin_group=None, child_actions=None, dependencies=None, display_text=None, enabled=None, gallery_image=None, help_text=None, login_enabled_mode=None, login_visibility_mode=None, name=None, parameters=None, visible=None, local_vars_configuration=None):  # noqa: E501
        """Action - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._action_command = None
        self._action_type = None
        self._always_text_and_image = None
        self._begin_group = None
        self._child_actions = None
        self._dependencies = None
        self._display_text = None
        self._enabled = None
        self._gallery_image = None
        self._help_text = None
        self._login_enabled_mode = None
        self._login_visibility_mode = None
        self._name = None
        self._parameters = None
        self._visible = None
        self.discriminator = None

        if action_command is not None:
            self.action_command = action_command
        if action_type is not None:
            self.action_type = action_type
        if always_text_and_image is not None:
            self.always_text_and_image = always_text_and_image
        if begin_group is not None:
            self.begin_group = begin_group
        if child_actions is not None:
            self.child_actions = child_actions
        if dependencies is not None:
            self.dependencies = dependencies
        if display_text is not None:
            self.display_text = display_text
        if enabled is not None:
            self.enabled = enabled
        if gallery_image is not None:
            self.gallery_image = gallery_image
        if help_text is not None:
            self.help_text = help_text
        if login_enabled_mode is not None:
            self.login_enabled_mode = login_enabled_mode
        if login_visibility_mode is not None:
            self.login_visibility_mode = login_visibility_mode
        if name is not None:
            self.name = name
        if parameters is not None:
            self.parameters = parameters
        if visible is not None:
            self.visible = visible

    @property
    def action_command(self):
        """Gets the action_command of this Action.  # noqa: E501


        :return: The action_command of this Action.  # noqa: E501
        :rtype: str
        """
        return self._action_command

    @action_command.setter
    def action_command(self, action_command):
        """Sets the action_command of this Action.


        :param action_command: The action_command of this Action.  # noqa: E501
        :type: str
        """

        self._action_command = action_command

    @property
    def action_type(self):
        """Gets the action_type of this Action.  # noqa: E501


        :return: The action_type of this Action.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this Action.


        :param action_type: The action_type of this Action.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "OneStep", "Command", "BuiltIn", "Category", "SearchGrp", "Report", "Dashboard", "Calendar", "Visualization", "Group", "Page", "DocRepository", "PortalCommand", "ActionCatalog", "OneStepForRecord"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and action_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `action_type` ({0}), must be one of {1}"  # noqa: E501
                .format(action_type, allowed_values)
            )

        self._action_type = action_type

    @property
    def always_text_and_image(self):
        """Gets the always_text_and_image of this Action.  # noqa: E501


        :return: The always_text_and_image of this Action.  # noqa: E501
        :rtype: bool
        """
        return self._always_text_and_image

    @always_text_and_image.setter
    def always_text_and_image(self, always_text_and_image):
        """Sets the always_text_and_image of this Action.


        :param always_text_and_image: The always_text_and_image of this Action.  # noqa: E501
        :type: bool
        """

        self._always_text_and_image = always_text_and_image

    @property
    def begin_group(self):
        """Gets the begin_group of this Action.  # noqa: E501


        :return: The begin_group of this Action.  # noqa: E501
        :rtype: bool
        """
        return self._begin_group

    @begin_group.setter
    def begin_group(self, begin_group):
        """Sets the begin_group of this Action.


        :param begin_group: The begin_group of this Action.  # noqa: E501
        :type: bool
        """

        self._begin_group = begin_group

    @property
    def child_actions(self):
        """Gets the child_actions of this Action.  # noqa: E501


        :return: The child_actions of this Action.  # noqa: E501
        :rtype: list[Action]
        """
        return self._child_actions

    @child_actions.setter
    def child_actions(self, child_actions):
        """Sets the child_actions of this Action.


        :param child_actions: The child_actions of this Action.  # noqa: E501
        :type: list[Action]
        """

        self._child_actions = child_actions

    @property
    def dependencies(self):
        """Gets the dependencies of this Action.  # noqa: E501


        :return: The dependencies of this Action.  # noqa: E501
        :rtype: list[str]
        """
        return self._dependencies

    @dependencies.setter
    def dependencies(self, dependencies):
        """Sets the dependencies of this Action.


        :param dependencies: The dependencies of this Action.  # noqa: E501
        :type: list[str]
        """

        self._dependencies = dependencies

    @property
    def display_text(self):
        """Gets the display_text of this Action.  # noqa: E501


        :return: The display_text of this Action.  # noqa: E501
        :rtype: str
        """
        return self._display_text

    @display_text.setter
    def display_text(self, display_text):
        """Sets the display_text of this Action.


        :param display_text: The display_text of this Action.  # noqa: E501
        :type: str
        """

        self._display_text = display_text

    @property
    def enabled(self):
        """Gets the enabled of this Action.  # noqa: E501


        :return: The enabled of this Action.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this Action.


        :param enabled: The enabled of this Action.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def gallery_image(self):
        """Gets the gallery_image of this Action.  # noqa: E501


        :return: The gallery_image of this Action.  # noqa: E501
        :rtype: str
        """
        return self._gallery_image

    @gallery_image.setter
    def gallery_image(self, gallery_image):
        """Sets the gallery_image of this Action.


        :param gallery_image: The gallery_image of this Action.  # noqa: E501
        :type: str
        """

        self._gallery_image = gallery_image

    @property
    def help_text(self):
        """Gets the help_text of this Action.  # noqa: E501


        :return: The help_text of this Action.  # noqa: E501
        :rtype: str
        """
        return self._help_text

    @help_text.setter
    def help_text(self, help_text):
        """Sets the help_text of this Action.


        :param help_text: The help_text of this Action.  # noqa: E501
        :type: str
        """

        self._help_text = help_text

    @property
    def login_enabled_mode(self):
        """Gets the login_enabled_mode of this Action.  # noqa: E501


        :return: The login_enabled_mode of this Action.  # noqa: E501
        :rtype: str
        """
        return self._login_enabled_mode

    @login_enabled_mode.setter
    def login_enabled_mode(self, login_enabled_mode):
        """Sets the login_enabled_mode of this Action.


        :param login_enabled_mode: The login_enabled_mode of this Action.  # noqa: E501
        :type: str
        """
        allowed_values = ["Anonymous", "LoggedIn", "Both"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and login_enabled_mode not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `login_enabled_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(login_enabled_mode, allowed_values)
            )

        self._login_enabled_mode = login_enabled_mode

    @property
    def login_visibility_mode(self):
        """Gets the login_visibility_mode of this Action.  # noqa: E501


        :return: The login_visibility_mode of this Action.  # noqa: E501
        :rtype: str
        """
        return self._login_visibility_mode

    @login_visibility_mode.setter
    def login_visibility_mode(self, login_visibility_mode):
        """Sets the login_visibility_mode of this Action.


        :param login_visibility_mode: The login_visibility_mode of this Action.  # noqa: E501
        :type: str
        """
        allowed_values = ["Anonymous", "LoggedIn", "Both"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and login_visibility_mode not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `login_visibility_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(login_visibility_mode, allowed_values)
            )

        self._login_visibility_mode = login_visibility_mode

    @property
    def name(self):
        """Gets the name of this Action.  # noqa: E501


        :return: The name of this Action.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Action.


        :param name: The name of this Action.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def parameters(self):
        """Gets the parameters of this Action.  # noqa: E501


        :return: The parameters of this Action.  # noqa: E501
        :rtype: list[KeyValuePairStringString]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this Action.


        :param parameters: The parameters of this Action.  # noqa: E501
        :type: list[KeyValuePairStringString]
        """

        self._parameters = parameters

    @property
    def visible(self):
        """Gets the visible of this Action.  # noqa: E501


        :return: The visible of this Action.  # noqa: E501
        :rtype: bool
        """
        return self._visible

    @visible.setter
    def visible(self, visible):
        """Sets the visible of this Action.


        :param visible: The visible of this Action.  # noqa: E501
        :type: bool
        """

        self._visible = visible

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Action):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Action):
            return True

        return self.to_dict() != other.to_dict()
